/*

sgCounter - library which supports length control in form fields
author: Mariusz Tulikowski
company: SmartGroup
url: www.smartgroup.eu

varsion: 1.0

*/


(function($) {
    $.fn.sgCounter = function(options) {

        this.each(function(i, element) {
            var placement = $(element).attr('data-sgcounter-placement'),
                min = $(element).attr('data-sgcounter-min'),
                max = $(element).attr('data-sgcounter-max'),
                snippet,
            opts = $.extend( {}, $.fn.sgCounter.defaults, options );

            if (typeof max === typeof undefined || max === false) {
                return;
            }

            if (typeof min === typeof undefined || max === false) {
                min = 0;
            }

            snippet = '<div class="sg-counter">';
            if(opts.showRequiredNumber) snippet += opts.textCharactersRequired + ' ' + min + '-' + max + '.';
            snippet += opts.textCharactersEntered + ' <span>' + $(element).val().length + '</span></div>';

            $(element).focus(function() {
                $(this).parent().append(snippet);
                updateCounter($(this));
                markError($(this), opts, min, max);
            });

            $(element).keyup(function() {
                updateCounter($(this));
                markError($(this), opts, min, max);
            });

            $(element).blur(function() {
                $(this).parent().find('div.sg-counter').remove();
            });

        });

        function markError(element, opts, min, max) {
            if(opts.showErrors === true) {
                if($(element).val().length < min || $(element).val().length > max ) {
                    $(element).addClass(opts.errorClass);
                } else {
                    $(element).removeClass(opts.errorClass);
                }
            }
        }

        function updateCounter(element) {
            $(element).parent().find('div.sg-counter').find('span').html($(element).val().length);
        }
    };

    $.fn.sgCounter.defaults = {
        showErrors: false,
        errorClass: "error",
        showRequiredNumber: true,
        textCharactersRequired: "Characters required:",
        textCharactersEntered: "Entered:"
    };
})(jQuery);
